@@ -4,6 +4,7 @@ from time import sleep
 import asyncio
 import os
 
+
 from python_redis_orm.core import *
 
 
@@ -95,7 +96,8 @@ def basic_test(connection_pool, prefix):
         redis_root.register_models([
             TaskChallenge,
         ])
-        for i in range(5):
+        count = 5
+        for i in range(count):
             TaskChallenge(
                 redis_root=redis_root,
                 status='in_work',
@@ -103,9 +105,9 @@ def basic_test(connection_pool, prefix):
         task_challenges_without_keys = redis_root.get(TaskChallenge)
         task_challenges_with_keys = redis_root.get(TaskChallenge, return_dict=True)
         have_exception = False
-        if not len(task_challenges_without_keys):
+        if not len(task_challenges_without_keys) == count:
             have_exception = True
-        if not task_challenges_with_keys:
+        if not len(task_challenges_with_keys) == count:
             have_exception = True
         else:
             if not task_challenges_with_keys.keys():
@@ -762,8 +764,7 @@ def performance_test(connection_pool, prefix):
             
             print(f'\n\n\n'
                   f'Performance test results on your machine:\n'
-                  f'Every test creates {test_confs_results[0][1]} instances of {model.__name__} model,\n'
-                  f'So every test creates {test_confs_results[0][2]} fields\n'
+                  f'Every test creates {test_confs_results[0][1]} instances ({test_confs_results[0][2]} fields) of {model.__name__} model,\n'
                   f'Here is the results:\n'
                   f'\n')
             
@@ -775,7 +776,7 @@ def performance_test(connection_pool, prefix):
                 if test_confs_result[0] == min_time:
                     min_conf_text = test_conf_text
             print(f'\n\n'
-                  f'Best configuration: {min_conf_text}\n')
+                  f'The best configuration: {min_conf_text}\n')
         
         count = 1000
         model = TaskChallenge
@@ -849,4 +850,4 @@ def run_tests():
 if __name__ == '__main__':
     results = run_tests()
     if not results:
-        sys.exit(1)
+        sys.exit(1)
\ No newline at end of file
